<?php

namespace Drupal\search_tracking\Controller;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides coordinates and stores in session.
 */
class SearchTrackingController extends ControllerBase {

  /**
   * The database connection used to store flood event information.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * The page cache disabling policy.
   *
   * @var \Drupal\Core\PageCache\ResponsePolicy\KillSwitch
   */
  protected $pageCacheKillSwitch;

  /**
   * Construct the DatabaseBackend.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection which will be used to store the flood event
   *   information.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack used to retrieve the current request.
   * @param \Drupal\Component\Datetime\TimeInterface|null $time
   *   The time service.
   */
  public function __construct(Connection $connection, RequestStack $request_stack, TimeInterface $time = NULL) {
    $this->connection = $connection;
    $this->requestStack = $request_stack;
    $this->time = $time;
  }

  /**
   * {@inheritdoc}
   */
  /*public static function create(ContainerInterface $container) {
  return new static(
  $container->get('database'),
  $container->get('requestStack'),
  );
  }*/

  /**
   * Implements FormData().
   */
  public function formData() {
    $jsonData = file_get_contents('php://input');
    $keyword = json_decode($jsonData, TRUE);
    if ($keyword['name']) {
      // $connection = \Drupal::service('database');
      $this->connection->insert('search_tracking')
        ->fields([
          'search' => $keyword['name'],
          'ip_address' => $this->requestStack->getCurrentRequest()->getClientIp(),
          'created_on' => date('Y-m-d H:i:s', $this->time->getCurrentTime()),
          // Add more fields as needed.
        ])
        ->execute();
    }
    return new JsonResponse();
  }

  /**
   * Implements SearchTracking()
   */
  public function searchTracking() {
    $database = $this->connection();
    $query = $database->query("SELECT id,search,ip_address,created_on FROM `search_tracking`");
    $result = $query->fetchAll();
    // \Drupal::service('page_cache_kill_switch')->trigger();
    $this->container->get('page_cache_kill_switch');
    return [
      '#theme' => 'search_tracking',
      '#items' => $result,
    ];
  }

}
